@@ -123,6 +123,7 @@ addItems <- function(id, data) {
 #' @export
 removeItem <- function(id, itemId) {
   method <- "removeItem"
+  itemId <- as.character(itemId)
   callJS()
 }
 
@@ -267,7 +268,7 @@ removeCustomTime <- function(id, itemId) {
 #' @param options Named list of options controlling the animation. Most common
 #' option is \code{"animation" = TRUE/FALSE}. For a full list of options, see
 #' the "fit" method in the
-#' \href{https://visjs.org/docs/timeline/#Methods}{official
+#' \href{https://visjs.github.io/vis-timeline/docs/timeline/#Methods}{official
 #' Timeline documentation}
 #' @examples
 #' if (interactive()) {
@@ -301,7 +302,7 @@ fitWindow <- function(id, options) {
 #' @param options Named list of options controlling the animation. Most common
 #' option is \code{"animation" = TRUE/FALSE}. For a full list of options, see
 #' the "moveTo" method in the
-#' \href{https://visjs.org/docs/timeline/#Methods}{official
+#' \href{https://visjs.github.io/vis-timeline/docs/timeline/#Methods}{official
 #' Timeline documentation}
 #' @examples
 #'
@@ -337,7 +338,7 @@ centerTime <- function(id, time, options) {
 #' @param options Named list of options controlling mainly the animation.
 #' Most common option is \code{"animation" = TRUE/FALSE}. For a full list of
 #' options, see the "focus" method in the
-#' \href{https://visjs.org/docs/timeline/#Methods}{official
+#' \href{https://visjs.github.io/vis-timeline/docs/timeline/#Methods}{official
 #' Timeline documentation}
 #' @examples
 #'
@@ -372,6 +373,7 @@ centerTime <- function(id, time, options) {
 #' @export
 centerItem <- function(id, itemId, options) {
   method <- "centerItem"
+  itemId <- as.character(itemId)
   callJS()
 }
 
@@ -498,7 +500,7 @@ setOptions <- function(id, options) {
 #' Most common options are \code{focus = TRUE/FALSE} and
 #' \code{"animation" = TRUE/FALSE}. For a full list of options, see
 #' the "setSelection" method in the
-#' \href{https://visjs.org/docs/timeline/#Methods}{official
+#' \href{https://visjs.github.io/vis-timeline/docs/timeline/#Methods}{official
 #' Timeline documentation}
 #' @examples
 #'
@@ -537,7 +539,7 @@ setSelection <- function(id, itemId, options) {
 #' @param options Named list of options controlling mainly the animation.
 #' Most common option is \code{animation = TRUE/FALSE}. For a full list of
 #' options, see the "setWindow" method in the
-#' \href{https://visjs.org/docs/timeline/#Methods}{official
+#' \href{https://visjs.github.io/vis-timeline/docs/timeline/#Methods}{official
 #' Timeline documentation}
 #' @examples
 #'
