@@ -107,6 +107,21 @@ HTMLWidgets.widget({
           }
         }
 
+        // set the custom configuration options
+        if (Array === opts.options.constructor) {
+          opts['options'] = {};
+        }
+        if (opts['height'] !== null &&
+            typeof opts['options']['height'] === "undefined") {
+          opts['options']['height'] = opts['height'];
+        }
+        if (opts['timezone'] !== null) {
+          opts['options']['moment'] = function(date) {
+            return vis.moment(date).utcOffset(opts['timezone']);
+          };
+        }
+        timeline.setOptions(opts.options);
+
         // set the data items and groups
         timeline.itemsData.clear();
         timeline.itemsData.add(opts.items);
@@ -125,21 +140,6 @@ HTMLWidgets.widget({
           zoomMenu.removeAttribute("data-show-zoom");
         }
 
-        // set the custom configuration options
-        if (Array === opts.options.constructor) {
-          opts['options'] = {};
-        }
-        if (opts['height'] !== null &&
-            typeof opts['options']['height'] === "undefined") {
-          opts['options']['height'] = opts['height'];
-        }
-        if (opts['timezone'] !== null) {
-          opts['options']['moment'] = function(date) {
-            return vis.moment(date).utcOffset(opts['timezone']);
-          };
-        }
-        timeline.setOptions(opts.options);
-
         // Now that the timeline is initialized, call any outstanding API
         // functions that the user wantd to run on the timeline before it was
         // ready
@@ -230,6 +230,11 @@ HTMLWidgets.widget({
         timeline.moveTo(params.time, params.options);
       },
       centerItem : function(params) {
+         if (typeof params.options === 'undefined') {
+          params.options = { 'zoom' : false };
+        } else if (typeof params.options.zoom === 'undefined') {
+          params.options.zoom = false;
+        }
         timeline.focus(params.itemId, params.options);
       },
       setItems : function(params) {
@@ -237,8 +242,7 @@ HTMLWidgets.widget({
         timeline.itemsData.add(params.data);
       },
       setGroups : function(params) {
-        timeline.groupsData.clear();
-        timeline.groupsData.add(params.data);
+        timeline.setGroups(params.data);
       },
       setOptions : function(params) {
         timeline.setOptions(params.options);
