@@ -24,3 +24,14 @@ test_that("dataframeToD3 works with NA values", {
                list(name = "Ben", age = "24"))
   expect_identical(dataframeToD3(df), list)
 })
+
+test_that("dataframeToD3 errors when given a non-dataframe", {
+  expect_error(dataframeToD3(50), "input must be a dataframe")
+  expect_error(dataframeToD3(FALSE), "input must be a dataframe")
+})
+
+test_that("dataframeToD3 returns the same whether the dataframe is pure or merged", {
+  df <- data.frame(name = c("Dean", "Ben"), age = c(27, 24))
+  df_rbind <- rbind(df[1, ], df[2, ])
+  expect_identical(dataframeToD3(df), dataframeToD3(df_rbind))
+})
